//Copyright © 2015-2017, Verizon and/or its Licensors. All rights reserved.

#import "UIViewController+Contact.h"
#import "PCContact+Additions.h"
#import "UIViewController+Alert.h"

@implementation UIViewController (Contact)

#pragma mark - abstract method

- (NSString *)stringForContactAction:(ContactAction)action {
    
    switch (action) {
        case deleteContactAction:
            return NSLocalizedString(@"Delete Contact", nil);
            break;
        case updateContactAction:
            return NSLocalizedString(@"Update Contact", nil);
            break;
        case createContactAction:
            return NSLocalizedString(@"Create Contact", nil);
            break;
        default:
            return nil;
            break;
    }
}

- (void)didBeginDoingContactAction:(ContactAction)action {
    // abstract method
}

- (void)didFinishDoingContactAction:(ContactAction)action onContact:(id)contact result:(id)result response:(id)response {
    // abstract method
}


#pragma mark -

- (void)executeAction:(ContactAction)action forContact:(PCContact *)contact {
    
    switch (action) {
        case saveContactAction:
            [self saveContact:contact];
            break;
        default:
            break;
    }
}

#pragma mark -

- (void)saveContact:(PCContact *)contact {

    CNMutableContact *CNContact = [contact getCNContact];
    
    CNContactStore *contactStore = [CNContactStore new];
    CNSaveRequest *saveRequest = [CNSaveRequest new];
    [saveRequest addContact:CNContact toContainerWithIdentifier:nil];
    
    NSError *error = nil;
    [contactStore executeSaveRequest:saveRequest error:&error];
    
    if (error) {
        
        [self showOKAlertWithTitle:NSLocalizedString(@"Failed", nil)
                                 andMessage:NSLocalizedString(@"Failed to save contact in addressbook", nil)
                           attributedString:nil
                                   okAction:nil];
    } else {
        
        [self showOKAlertWithTitle:NSLocalizedString(@"Success", nil)
                                 andMessage:NSLocalizedString(@"Successfully saved contact in addressbook", nil)
                           attributedString:nil
                                   okAction:nil];
    }
}

#pragma mark -
#pragma mark Cancel
- (void)addCancelAction:(UIAlertController *)alertController {
    [self alertController:alertController
       addActionWithTitle:NSLocalizedString(@"Cancel", nil)
                    style:UIAlertActionStyleCancel
                andAction:nil];
}
#pragma mark -

- (void)addSaveContactAction:(UIAlertController *)alertController forSelectedContact:(PCContact *)selectedContact {
    __weak UIViewController *blocksafeSelf = self;
    [self alertController:alertController
       addActionWithTitle:NSLocalizedString(@"Save Contact", nil)
                    style:UIAlertActionStyleDefault
                andAction:^(UIAlertAction * _Nonnull action) {
                    
                    [blocksafeSelf saveContact:selectedContact];
                }];
}

- (void)addDeleteContactAction:(UIAlertController *)alertController forSelectedContact:(PCContact *)selectedContact {
    
    __weak UIViewController *blocksafeSelf = self;
    [self alertController:alertController
       addActionWithTitle:[self stringForContactAction:deleteContactAction]
                    style:UIAlertActionStyleDestructive
                andAction:^(UIAlertAction * _Nonnull action) {
                    
                    NSString *message = NSLocalizedString(@"Are you sure want to delete contact", nil);
                    
                    
                    [blocksafeSelf showOKCancelAlertWithTitle:NSLocalizedString(@"Warning", nil)
                                                   andMessage:message
                                                     okAction:^(UIAlertAction *action) {
                                                       [blocksafeSelf didBeginDoingContactAction:deleteContactAction];
                                                         
                                                         /*
                                                          @Description :
                                                          This API is used to delete a specific contact. Once the delete process is succeed/failed result will come with completion block.
                                                          
                                                          @Parameters :
                                                          PCDeleteContactAPIParams:
                                                          * This class stores all the parameters required to delete contact from user account.It contains attributes such as contactId.
                                                          * For providing access token to SDK user have to logged In.
                                                          * contactId is required parameter to call this API.
                                                          * If user will not provide required parameter, API will throw an NSInvalidArgumentException and user have to handle it.
                                                          * More information about parameters you will find in PCDeleteContactAPIParams.h class.
                                                          
                                                          @CompletionHandler :
                                                          This completion block gets called once the delete process is succeed/failed. completion block contains below parameter.
                                                          PCAPIQueryResponse : Stores all the server response and error for this API.
                                                          
                                                          @To delete a specific contact, you must take the following steps:
                                                          * Include VerizonCloudAPI.framework header file in your class.
                                                          #import <VerizonCloudAPI/VerizonCloudAPI.h>
                                                          * Initalize the PCDeleteContactAPIParams class and provide the required parameter.
                                                          * Initalize the PCAPISDK object and call the  deleteContact:withCompletionHandler: API.
                                                          * Perform the  deleteContact:withCompletionHandler: API call using the code sample below.
                                                          * Get the result (succeed or failed) in completion block.
                                                          * If session is no longer valid , call the logout API which remove Access token stored in keychain. Again call authenticate:fromViewController:withCompletionHandler: API to get Access token.
                                                          */
                                                         
                                                         // Initilize the PCAPISDK and call the API.
                                                         
                                                         PCDeleteContactAPIParams *params = [[PCDeleteContactAPIParams alloc] init];
                                                         params.contactID = selectedContact.ID;
                                                         
                                                         [[PCAPISDK sharedInstance] deleteContact:params withCompletionHandler:^(PCAPIQueryResponse *response) {
                                                             [blocksafeSelf didFinishDoingContactAction:deleteContactAction onContact:selectedContact result:nil response:response];
                                                         }];
                                                         
                                                     }
                                                 cancelAction:^(UIAlertAction *action) {
                                                     
                                                 }];
                }];

}


- (void)showActionsForSelectedContact:(PCContact *)selectedContact {

    UIAlertController *alertController = [UIAlertController alertControllerWithTitle:selectedContact.firstName
                                                                             message:nil
                                                                      preferredStyle:UIAlertControllerStyleActionSheet];
    
    
    
    [self addSaveContactAction:alertController forSelectedContact:selectedContact];
    [self addDeleteContactAction:alertController forSelectedContact:selectedContact];
    [self addCancelAction:alertController];
    
    [self presentViewController:alertController animated:YES completion:nil];
}

@end
