//Copyright © 2015-2017, Verizon and/or its Licensors. All rights reserved.

#import "ContactDetailViewController.h"
#import "UIViewController+Contact.h"
#import "CNContact+Additions.h"
#import "UIViewController+Alert.h"
#import "UIViewController+Spinner.h"

@implementation ContactDetailViewController

- (void)viewDidLoad {

    [super viewDidLoad];
}

#pragma mark -
#pragma CNContactViewControllerDelegate

- (BOOL)contactViewController:(CNContactViewController *)viewController shouldPerformDefaultActionForContactProperty:(CNContactProperty *)property {
    return YES;
}

/*!
 * @abstract Called when the view has completed.
 * @discussion If creating a new contact, the new contact added to the contacts list will be passed.
 * If adding to an existing contact, the existing contact will be passed.
 * @note It is up to the delegate to dismiss the view controller.
 */
- (void)contactViewController:(CNContactViewController *)viewController didCompleteWithContact:(nullable CNContact *)contact {
    
    if (contact) {
        
        /*
         @Description :
         This API is used to update a specific contact. Once the update process is succeed/failed result will come with completion block.
         
         @Parameters :
         PCUpdateContactAPIParams:
         * This class stores all the parameters required to update contact from user account.
         * For providing access token to SDK user have to logged In.
         * contactID and version are required parameter to call this API.
         * If user will not provide required parameter, API will throw an NSInvalidArgumentException and user have to handle it.
         * More information about parameters you will find in PCUpdateContactAPIParams.h class.
         
         @CompletionHandler :
         This completion block gets called once the update process is succeed/failed. completion block contains below parameter.
         PCContact : Stores update contact details.
         PCAPIQueryResponse : Stores all the server response and error for this API.
         
         @To update a specific contact, you must take the following steps:
         * Include VerizonCloudAPI.framework header file in your class.
         #import <VerizonCloudAPI/VerizonCloudAPI.h>
         * Initalize the PCUpdateContactAPIParams class and provide the required parameter.
         * Initalize the PCAPISDK object and call the updateContact:withCompletionHandler: API.
         * User can also able to initalize PCUpdateContactAPIParams using PCContact through initWithPCContact method.
         * Perform the updateContact:withCompletionHandler: API call using the code sample below.
         * Get the result (succeed or failed) in completion block.
         * If session is no longer valid , call the logout API which remove Access token stored in keychain. Again call authenticate:fromViewController:withCompletionHandler: API to get Access token.
         */
        
        // Initilize the PCAPISDK and call the API.
        
        PCUpdateContactAPIParams *params = [[PCUpdateContactAPIParams alloc] initWithPCContact:[contact getPCContact]];
        params.version = self.selectedContact.version;
        params.contactID = self.selectedContact.ID;
        params.incaseOfEmergency = self.selectedContact.incaseOfEmergency;
        params.favorite = self.selectedContact.favorite;
        
        __weak ContactDetailViewController *blockself = self;
        [self showSpinner];
        
        [[PCAPISDK sharedInstance] updateContact:params withCompletionHandler:^(PCContact *contact, PCAPIQueryResponse *response) {
            
            [self hideSpinner];
            
            PCAPIQueryResponse *APIResponse = (PCAPIQueryResponse *)response;
            switch (APIResponse.urlResponse.statusCode) {
                case PCAPIResponseCodeResourceCreated:
                case PCAPIResponseCodeNoContent:
                case PCAPIResponseCodeOK: {
                    [blockself.contactDelegate updateOldContact:self.selectedContact withUpdatedContact:contact];
                    [blockself.navigationController popViewControllerAnimated:YES];
                }
                    break;
                case PCAPIResponseCodeUnauthorized:
                    [blockself showUnAuthorizedAlert];
                    break;
                case PCAPIResponseCodeServiceUnavailable:
                    [blockself showServerUnavailableAlert];
                    break;
                default:
                    [blockself showOperationFailedAlert:[self stringForContactAction:updateContactAction]];
                    break;
            }
        }];
    }else{
        [self.navigationController popViewControllerAnimated:YES];
    }
}


@end
